@@ -1,9 +1,12 @@
--- | Partial functions.
+-- | Partial functions. Import as:
 --
+-- > import qualified RIO.Partial as RIO'
 module RIO.Partial
   ( Data.Maybe.fromJust
   , Prelude.read
   , Prelude.toEnum
+  , Prelude.pred
+  , Prelude.succ
   ) where
 
 import qualified Data.Maybe
