@@ -8,17 +8,21 @@ module RIO.Prelude.Renames
   , GVector
   , toStrictBytes
   , fromStrictBytes
+  , yieldThread
   ) where
 
-import RIO.Prelude.Reexports
+import Prelude
+import qualified Data.ByteString          as B
 import qualified Data.ByteString.Lazy     as BL
 import qualified Data.Vector.Generic      as GVector
 import qualified Data.Vector.Storable     as SVector
 import qualified Data.Vector.Unboxed      as UVector
 import qualified Data.Text.Lazy           as TL
 import qualified Data.Semigroup
+import UnliftIO (MonadIO)
+import qualified UnliftIO.Concurrent (yield)
 
-sappend :: Semigroup s => s -> s -> s
+sappend :: Data.Semigroup.Semigroup s => s -> s -> s
 sappend = (Data.Semigroup.<>)
 
 type UVector = UVector.Vector
@@ -28,8 +32,12 @@ type GVector = GVector.Vector
 type LByteString = BL.ByteString
 type LText = TL.Text
 
-toStrictBytes :: LByteString -> ByteString
+toStrictBytes :: LByteString -> B.ByteString
 toStrictBytes = BL.toStrict
 
-fromStrictBytes :: ByteString -> LByteString
+fromStrictBytes :: B.ByteString -> LByteString
 fromStrictBytes = BL.fromStrict
+
+yieldThread :: MonadIO m => m ()
+yieldThread = UnliftIO.Concurrent.yield
+{-# INLINE yieldThread #-}
